encoding: In BinaryXmlEncoder class constructor, added parameter initialLength.
diff --git a/src/encoding/binary-xml-encoder.hpp b/src/encoding/binary-xml-encoder.hpp
index 33afb09..5961891 100644
--- a/src/encoding/binary-xml-encoder.hpp
+++ b/src/encoding/binary-xml-encoder.hpp
@@ -21,9 +21,10 @@
 class BinaryXmlEncoder : public ndn_BinaryXmlEncoder {
 public:
   /**
    * Initialize the base ndn_BinaryXmlEncoder struct with an initial array of 16 bytes.  Use simpleRealloc.
    */
-  BinaryXmlEncoder() 
+  BinaryXmlEncoder(size_t initialLength = 16) 
   : output_(16)
   {
     ndn_BinaryXmlEncoder_initialize(this, &output_);
@@ -21,9 +21,10 @@
 public:
   /**
-   * Initialize the base ndn_BinaryXmlEncoder struct with an initial array of 16 bytes.  Use simpleRealloc.
+   * Initialize the base ndn_BinaryXmlEncoder struct with the initialLength.  Use simpleRealloc.
+   * @param initialLength The initial size of the output.  If omitted, use 16.
    */